dwww Home | Manual pages | Find package

nvidia-xconfig(1)           General Commands Manual           nvidia-xconfig(1)

NAME
       nvidia-xconfig - manipulate X configuration files for the NVIDIA driver

SYNOPSIS
       nvidia-xconfig [ options ]

DESCRIPTION
       nvidia-xconfig is a tool intended to provide basic control over configu-
       ration options available in the NVIDIA X driver.

       nvidia-xconfig performs its operations in several steps:

       1)     The  system  X  configuration file is found and read into memory.
              If no configuration file can be found,  nvidia-xconfig  generates
              one  from  scratch  using default settings; in this case, nvidia-
              xconfig will write the configuration to /etc/X11/xorg.conf

       2)     The configuration in memory is modified  to  support  the  NVIDIA
              driver.    This  consists  of  changing  the  display  driver  to
              "nvidia", removing the commands to load the  "GLcore"  and  "dri"
              modules, and adding the command to load the "glx" module.

       3)     The  configuration in memory is modified according to the options
              specified on the command line.  Please see the NVIDIA README  for
              a  description  of the NVIDIA X configuration file options.  Note
              that nvidia-xconfig does not perform any validation of the X con-
              figuration file options requested on the command line; X configu-
              ration file option validation is left for the NVIDIA X driver.

       4)     The configuration is written back to the file from which  it  was
              read.   A  backup  of  the original configuration is created with
              ".backup" appended.  For example,  if  your  X  configuration  is
              /etc/X11/xorg.conf   then   nvidia-xconfig   will   copy   it  to
              /etc/X11/xorg.conf.backup before writing the  new  configuration.
              The --post-tree (-T) option can be used to print the new configu-
              ration to standard out in tree form instead.  This option is use-
              ful to see what nvidia-xconfig will do while leaving the original
              configuration intact.

       The  source  code to nvidia-xconfig is released under the GPL and avail-
       able here:

            ⟨https://download.nvidia.com/XFree86/nvidia-xconfig/⟩

       Patches are welcome.

OPTIONS
       -c XCONFIG, --xconfig=XCONFIG
              Use XCONFIG as the input X config file; if  this  option  is  not
              specified, then the same search path used by the X server will be
              used to find the X configuration file.

       -o OUTPUT-XCONFIG, --output-xconfig=OUTPUT-XCONFIG
              Use  OUTPUT-XCONFIG  as  the output X configuration file; if this
              option is not specified, then the input X configuration  filename
              will also be used as the output X configuration filename.

       -s, --silent
              Run  silently;  no messages will be printed to stdout, except for
              warning and error messages to stderr.

       -t, --tree
              Read the X configuration file, print to stdout the  X  configura-
              tion data in a tree format, and exit.

       -v, --version
              Print the nvidia-xconfig version and exit.

       -h, --help
              Print  usage  information  for the common commandline options and
              exit.

       -A, --advanced-help
              Print usage information for the  common  commandline  options  as
              well as the advanced options, and then exit.

ADVANCED OPTIONS
       --acpid-socket-path=ACPID-SOCKET-PATH, --no-acpid-socket-path
              Set  this  option  to specify an alternate path to the Linux ACPI
              daemon (acpid)'s socket, which the NVIDIA X driver  will  use  to
              connect to acpid.

       --add-argb-glx-visuals, --no-add-argb-glx-visuals
              Enables or disables support for OpenGL rendering into 32-bit ARGB
              windows and pixmaps.

       --allow-glx-with-composite, --no-allow-glx-with-composite
              Enable or disable the "AllowGLXWithComposite" X configuration op-
              tion.

       --busid=BUSID, --no-busid
              This  option  writes the specified BusID to the device section of
              the X configuration file.  If there are multiple device sections,
              then it adds the BusID field to each of them.  To add  the  BusID
              to  only  a specific device or screen section, use the '--device'
              or '--screen' options.

       --preserve-busid, --no-preserve-busid
              By default, nvidia-xconfig preserves the existing BusID in the  X
              configuration  file  only if there are multiple X screens config-
              ured for the X  server.   Use  '--preserve-busid'  or  '--no-pre-
              serve-busid' to force the BusID to be preserved or not preserved,
              overriding the default behavior.

       --cool-bits=COOL-BITS, --no-cool-bits
              Enable or disable the "Coolbits" X configuration option.  Setting
              this option will enable support in the NV-CONTROL X extension for
              manipulating  GPU  clock  and  GPU  fan control settings. Default
              value is 0.  For fan control set it  to  4.   WARNING:  this  may
              cause system damage and void warranties.

       --composite, --no-composite
              Enable or disable the "Composite" X extension.

       --connected-monitor=CONNECTED-MONITOR, --no-connected-monitor
              Enable or disable the  "ConnectedMonitor" X configuration option;
              setting this option forces the X driver to behave as if the spec-
              ified display devices are connected to the GPU.

       --connect-to-acpid, --no-connect-to-acpid
              Enable  or  disable  the "ConnectToAcpid" X configuration option.
              If this option is set, the NVIDIA X driver will attempt  to  con-
              nect to the Linux ACPI daemon (acpid).  Set this option to off to
              prevent the X driver from attempting to connect to acpid.

       --constant-dpi, --no-constant-dpi
              Enable or disable the "ConstantDPI" X configuration option, which
              controls  whether  the  NVIDIA X driver maintains a constant dots
              per inch (DPI) value by recomputing the reported size in millime-
              ters of the X screen when XRandR changes the size  in  pixels  of
              the X screen.

       --custom-edid=CUSTOM-EDID, --no-custom-edid
              Enable  or disable the  "CustomEDID" X configuration option; set-
              ting this option forces the X  driver  to  use  the  EDID  speci-
              fied.This  option  is a semicolon-separated list of pairs of dis-
              play device names and  filename  pairs;  e.g  "CRT-0:mp\did.bin".
              Note  that a display device name must always be specified even if
              only one EDID is specified.

       --dac-8bit, --no-dac-8bit
              Most Quadro parts by default use a 10 bit  color  look  up  table
              (LUT) by default; setting this option to TRUE forces these graph-
              ics chips to use an 8 bit (LUT).

       -d DEPTH, --depth=DEPTH
              Set  the  default  depth to DEPTH ; valid values for DEPTH are 8,
              15, 16, 24, and 30.

       --device=DEVICE
              The nvidia-xconfig utility operates on one or more devices in the
              X configuration file.  If this option is  specified,  the  device
              named  DEVICE  in the X configuration file will be used.  If this
              option is not specified, all the devices within the X  configura-
              tion file will be used.

       --disable-glx-root-clipping, --no-disable-glx-root-clipping
              Disable  or  enable  clipping OpenGL rendering to the root window
              via the "DisableGLXRootClipping" X configuration option.

       --damage-events, --no-damage-events
              Use OS-level events to notify the X server when a  direct-render-
              ing client has performed rendering that needs to be composited to
              the screen.  Improves performance when using GLX with the compos-
              ite extension.

       --preserve-driver-name
              By  default  nvidia-xconfig  changes  the   display   driver   to
              "nvidia" for all configured X screens; this option preserves  the
              existing driver name of each X screen.

       --egpu, --no-egpu
              Enable or disable the "AllowExternalGpus" X configuration option.

       -a, --enable-all-gpus
              Delete  all existing X screens in the current configuration, then
              configure an X screen on every GPU in your system.

       --exact-mode-timings-dvi, --no-exact-mode-timings-dvi
              Forces the initialization of the X server with the exact  timings
              specified in the ModeLine.

       -E FILE, --extract-edids-from-file=FILE
              Extract any raw EDID byte blocks contained in the specified X log
              file  LOG  ; raw EDID bytes are printed by the NVIDIA X driver to
              the X log as hexadecimal when verbose logging is enabled with the
              "-logverbose 6" X server commandline option.  Any extracted EDIDs
              are then written as binary data to individual files.  These files
              can later be used by the NVIDIA X driver through the "CustomEDID"
              X configuration option.

       --extract-edids-output-file=FILENAME
              When the '--extract-edids-from-file' option is used, nvidia-xcon-
              fig writes any extracted EDID to a file, typically "edid.bin"  in
              the  current  directory.  Use this option to specify an alternate
              filename.  Note that nvidia-xconfig, if necessary, will append  a
              unique number to the EDID filename, to avoid overwriting existing
              files (e.g., "edid.bin.1" if "edid.bin" already exists).

       --flatpanel-properties=FLATPANEL-PROPERTIES, --no-flatpanel-properties
              Set  the  flat  panel  properties.  The  supported properties are
              'dithering' and 'ditheringmode'.  Please see  the  NVIDIA  README
              'Appendix  B.  X Config Options' for more details on the possible
              values and syntax.

       --flip, --no-flip
              Enable or disable OpenGL flipping

       --force-generate
              Force generation of a new X config file,  ignoring  any  existing
              system  X  config  file.   This  is not typically recommended, as
              things like the mouse protocol, keyboard layout, font paths, etc,
              are setup by your Unix distribution.   While  nvidia-xconfig  can
              attempt  to  infer these values, it is best to use your Unix dis-
              tribution's  X  config  file  for  the  basis  of  anything  that
              nvidia-xconfig creates.

       --force-stereo-flipping, --no-force-stereo-flipping
              Normally,  stereo  flipping is only performed when a stereo draw-
              able is visible. This option forces stereo flipping even when  no
              stereo drawables are visible.

       --handle-special-keys=WHEN, --no-handle-special-keys
              Specify when the X server should use the builtin keyboard handler
              to process special key combinations (such as Ctrl+Alt+Backspace);
              see  the X configuration man page for details.  The value of WHEN
              can be 'Always', 'Never', or 'WhenNeeded'.

       --include-implicit-metamodes, --no-include-implicit-metamodes
              Enable or disable the "IncludeImplicitMetaModes" X  configuration
              option.

       --keyboard=KEYBOARD
              When generating a new X configuration file (which happens when no
              system  X configuration file can be found, or the '--force-gener-
              ate' option is specified), use KEYBOARD  as  the  keyboard  type,
              rather than attempting to probe the system for the keyboard type.
              For  a list of possible keyboard types, see the '--keyboard-list'
              option.

       --keyboard-driver=DRIVER
              In most cases nvidia-xconfig can automatically determine the cor-
              rect keyboard driver to use (either  'kbd'  or  'keyboard').  Use
              this  option  to override what nvidia-xconfig detects. Typically,
              if you are using an X.Org X server, use 'kdb'; if you  are  using
              an XFree86 X server, use 'keyboard'.

       --keyboard-list
              Print  to  stdout  the available keyboard types recognized by the
              '--keyboard' option, and then exit.

       --layout=LAYOUT
              The nvidia-xconfig utility operates on a Server Layout within the
              X configuration file.  If this option is  specified,  the  layout
              named  LAYOUT  in the X configuration file will be used.  If this
              option is not specified, the first Server Layout in the X config-
              uration file is used.

       --mode=MODE
              Add the specified mode to the mode list.

       --mode-debug, --no-mode-debug
              Enable or disable the "ModeDebug" X  configuration  option;  when
              enabled, this option causes the X driver to print verbose details
              about mode validation to the X log file.

       --mode-list=MODELIST
              Remove all existing modes from the X configuration's modelist and
              add the one(s) specified in the MODELIST string.

       --remove-mode=MODE
              Remove the specified mode from the mode list.

       --metamodes=METAMODES
              Add  the MetaMode X configuration option with the value METAMODES
              which will replace any existing MetaMode option already in the  X
              configuration file.

       --mouse=MOUSE
              When generating a new X configuration file (which happens when no
              system  X configuration file can be found, or the '--force-gener-
              ate' option is specified), use MOUSE as the  mouse  type,  rather
              than  attempting  to  probe the system for the mouse type.  For a
              list of possible mouse types, see the '--mouse-list' option.

       --mouse-list
              Print to stdout the  available  mouse  types  recognized  by  the
              '--mouse' option, and then exit.

       --multisample-compatibility, --no-multisample-compatibility
              Enable  or disable the use of separate front and back multisample
              buffers.

       --nvidia-cfg-path=PATH
              The nvidia-cfg library is used to  communicate  with  the  NVIDIA
              kernel  module to query basic properties of every GPU in the sys-
              tem.  This library is typically only used by nvidia-xconfig  when
              configuring multiple X screens.  This option tells nvidia-xconfig
              where  to look for this library (in case it cannot find it on its
              own).  This option should normally not be needed.

       --only-one-x-screen
              Disable all but one X screen.

       --overlay, --no-overlay
              Enable or disable the "Overlay" X configuration option.

       --cioverlay, --no-cioverlay
              Enable or disable the color index overlay.

       --overlay-default-visual, --no-overlay-default-visual
              Enable or disable the "OverlayDefaultVisual" X configuration  op-
              tion.

       --transparent-index=INDEX, --no-transparent-index
              Pixel  to  use  as  transparent  when using color index overlays.
              Valid values for TRANSPARENT-INDEX are 0-255.

       -T, --post-tree
              Like the '--tree' option, but goes through the  full  process  of
              applying  any  user requested updates to the X configuration, be-
              fore printing the final configuration to stdout in a tree format.
              Effectively, this option just  causes  the  configuration  to  be
              printed  to  stdout  as  a tree instead of writing the results to
              file.

       --power-connector-check, --no-power-connector-check
              Disable or enable the "NoPowerConnectorCheck" X configuration op-
              tion.

       --probe-all-gpus, --no-probe-all-gpus
              Disable or enable the "ProbeAllGpus" X configuration option.

       --query-gpu-info
              Print information about all recognized NVIDIA GPUs in the system.

       --registry-dwords=REGISTRY-DWORDS, --no-registry-dwords
              Enable or disable the "RegistryDwords" X configuration option.

       --render-accel, --no-render-accel
              Enable or disable the "RenderAccel" X configuration option.

       --render-extension, --no-render-extension
              Disable or enable the "NoRenderExtension" X configuration option.

       --screen=SCREEN
              The nvidia-xconfig utility operates on one or more screens within
              a Server Layout in the X configuration file.  If this  option  is
              specified,  the  screen  named SCREEN in the X configuration file
              will be used.  If this  option  is  not  specified,  all  screens
              within  the  selected  Server  Layout in the X configuration file
              will be used used.

       --separate-x-screens, --no-separate-x-screens
              A GPU that supports multiple simultaneous display devices can ei-
              ther drive these display devices in a single X screen, or as sep-
              arate X screens.  When the '--separate-x-screens' option is spec-
              ified, each GPU on which an X screen is currently configured will
              be updated to have two or more (depending on the capabilities  of
              that  GPU)  X  screens configured.  The '--no-separate-x-screens'
              option will remove any extra configured X screens  on  each  GPU.
              Please  see  the NVIDIA README description of "Separate X Screens
              on One GPU" for further details.

       --x-screens-per-gpu=X-SCREENS-PER-GPU
              A GPU that supports multiple simultaneous display devices can ei-
              ther drive these display devices in a single X screen, or as sep-
              arate X screens.  When the  '--x-screens-per-gpu=<quantity>'  op-
              tion  is  specified,  each  GPU on which an X screen is currently
              configured will be updated to have <quantity> X  screens.  <quan-
              tity> has to be greater than 0. Setting <quantity> to 1 is equiv-
              alent to specifying the '--no-separate-x-screens' option.  Please
              see  the  NVIDIA README description of "Separate X Screens on One
              GPU" for further details.

       --sli=SLI, --no-sli
              Enable or disable SLI.  Valid values for SLI are 'Off'  and  'Mo-
              saic'.

       --stereo=STEREO, --no-stereo
              Enable  or disable the stereo mode.  Valid values for STEREO are:
              0 (Disabled), 1 (DDC glasses), 2 (Blueline glasses),  3  (Onboard
              stereo),  4 (multi-display clone mode stereo), 5 (SeeReal digital
              flat  panel),  6  (Sharp3D   digital   flat   panel),   7   (Ari-
              sawa/Hyundai/Zalman/Pavione/Miracube),  8  (3D  DLP),  9  (3D DLP
              INV), 10 (NVIDIA 3D VISION), 11 (NVIDIA 3D VISION PRO), 12  (HDMI
              3D), 13 (Tridelity SL).

       --thermal-configuration-check, --no-thermal-configuration-check
              Disable or enable the "ThermalConfigurationCheck" X configuration
              option.

       --metamode-orientation=ORIENTATION, --no-metamode-orientation
              Specify  the  MetaModeOrientation.   Valid values for ORIENTATION
              are: "RightOf" (the  default),  "LeftOf",  "Above",  "Below",  or
              "Clone".

       --nvidia-xinerama-info, --no-nvidia-xinerama-info
              Enable  or disable providing Xinerama information from the NVIDIA
              X driver.

       --nvidia-xinerama-info-order=NVIDIA-XINERAMA-INFO-ORDER, --no-nvidia-
       xinerama-info-order
              Enable or disable the "nvidiaXineramaInfoOrder"  X  configuration
              option.   NVIDIA-XINERAMA-INFO-ORDER is a comma-separated list of
              display device names that describe the order in which  nvidiaXin-
              eramaInfo should be reported.  E.g., "CRT, DFP, TV".

       --ubb, --no-ubb
              Enable or disable the "UBB" X configuration option.

       --use-edid, --no-use-edid
              Enable  or  disable use of the EDID (Extended Display Identifica-
              tion Data) from your display device(s).  The EDID  will  be  used
              for  driver operations such as building lists of available modes,
              determining valid frequency ranges, and computing the  DPI  (Dots
              Per  Inch).   This  option  defaults to TRUE (the NVIDIA X driver
              will use the EDID, when available).  It is NOT  recommended  that
              you use this option to globally disable use of the EDID; instead,
              use  '--no-use-edid-freqs' or '--no-use-edid-dpi' to disable spe-
              cific uses of the EDID.

       --use-edid-dpi, --no-use-edid-dpi
              Enable or disable use of the physical  size  information  in  the
              display device's EDID, if any, to compute the DPI (Dots Per Inch)
              of the X screen.  This option defaults to TRUE (the NVIDIA X dri-
              ver uses the EDID's physical size, when available, to compute the
              DPI).

       --use-edid-freqs, --no-use-edid-freqs
              Enable  or  disable  use  of the HorizSync and VertRefresh ranges
              given in a display device's EDID, if any.   EDID  provided  range
              information  will  override  the HorizSync and VertRefresh ranges
              specified in the Monitor section.  This option defaults  to  TRUE
              (the  NVIDIA  X  driver  will  use frequency information from the
              EDID, when available).

       --use-display-device=DISPLAY-DEVICE, --no-use-display-device
              Force the X driver to use the display device specified.

       --use-events, --no-use-events
              Enable or disable "UseEvents"  X  configuration  option.  Setting
              this  option will enable the X driver to use the system events in
              some cases when it is waiting for the hardware. With this  option
              X driver sets an event handler and waits for the hardware through
              the poll() system call. This option defaults to FALSE.

       --virtual=WIDTHxHEIGHT, --no-virtual
              Specify the virtual screen resolution.

       --x-prefix=X-PREFIX
              The  X installation prefix; the default is /usr/X11R6/.  Only un-
              der rare circumstances should this option be needed.

       --color-space=COLORSPACE, --no-color-space
              Enable or disable the "ColorSpace" X configuration option.  Valid
              values for "COLORSPACE" are: "RGB" and "YCbCr444".

       --color-range=COLORRANGE, --no-color-range
              Sets  the  "ColorRange"  X configuration option. Valid values for
              "COLORRANGE" are: "Full" and "Limited".

       --3dvision-usb-path=3DVISION-USB-PATH
              Set this option to specify the sysfs path of  the  connected  USB
              dongle.

       --3dvisionpro-config-file=3DVISIONPRO-CONFIG-FILE
              Set  this  option to specify the NVIDIA 3DVisionPro configuration
              file. Ensure X server has a read and write access permissions  to
              this file. NVIDIA X driver stores the hub and the pairing config-
              uration  in this file to re-use across X restarts. If this option
              is not provided, 3D VisionPro configuration will not be stored.

       --3dvision-display-type=3DVISION-DISPLAY-TYPE, --no-3dvision-display-
       type
              When NVIDIA 3D Vision is enabled with a non 3D Vision ready  dis-
              play,  use  this option to specify the display type. Valid values
              are: 0 (Assume it is a CRT), 1 (Assume it is a DLP) and 2 (Assume
              it is a DLP TV and enable the checkerboard output).

       --base-mosaic, --no-base-mosaic
              Enable or disable the "BaseMosaic" X configuration option.

       --restore-original-backup
              Restore a backup of the X configuration that was made before  any
              changes  were  made by nvidia-xconfig, if such a backup is avail-
              able. This type of backup is made  by  nvidia-xconfig  before  it
              modifies  an  X  configuration  file  that  it has not previously
              touched; this is assumed to be an X configuration file that  pre-
              dates  the  involvement  of  the  NVIDIA X driver. As an example,
              nvidia-xconfig   will   copy   an   X   configuration   file   at
              /etc/X11/xorg.conf  to /etc/X11/xorg.conf.nvidia-xconfig-original
              the first time it makes changes to that file.

       --allow-empty-initial-configuration, --no-allow-empty-initial-configura-
       tion
              Allow the X server to start even if no connected display  devices
              could be detected.

       --inband-stereo-signaling, --no-inband-stereo-signaling
              Enable or disable the "InbandStereoSignaling" X configuration op-
              tion.

       --force-yuv-420, --no-force-yuv-420
              Enable  or  disable  the "ForceYUV420" X configuration option. If
              the current display and GPU both support uncompressed  RGB  4:4:4
              output  and  YUV  4:2:0  compressed output with the current mode,
              then RGB 4:4:4 output is selected by default. This option  forces
              the use of YUV 4:2:0 output (where supported) instead.

       --force-composition-pipeline=FORCE-COMPOSITION-PIPELINE, --no-force-com-
       position-pipeline
              Enable  or disable the "ForceCompositionPipeline" X configuration
              option.

       --force-full-composition-pipeline=FORCE-FULL-COMPOSITION-PIPELINE,
       --no-force-full-composition-pipeline
              Enable or disable the "ForceFullCompositionPipeline" X configura-
              tion option.

       --allow-hmd=ALLOW-HMD, --no-allow-hmd
              Enable or disable the "AllowHMD" X configuration option.

       --prime, --no-prime
              Enable PRIME for the generated X config file. Cannot be run  with
              --no-busid or --no-allow-empty-initial-configuration. On a system
              with  more  than  1  GPU,  specify  the GPU to use for PRIME with
              --busid or the first available will be chosen. Note that  to  en-
              able  PRIME  it  is necessary to run "xrandr --setprovideroutput-
              source modesetting NVIDIA-0" and "xrandr  --auto"  after  comple-
              tion.

EXAMPLES
       nvidia-xconfig
              Reads  an  existing X config file and adapts it to use the NVIDIA
              driver.  If no X config file can be found, a new one  is  created
              at /etc/X11/xorg.conf with default settings.

       nvidia-xconfig --post-tree --metamode-orientation=clone
              Reads  the existing X configuration file, adds the MetaModeOrien-
              tation option, and then prints the resulting config file to stan-
              dard out in tree form.  The configuration file is not modified.

       nvidia-xconfig --enable-all-gpus
              Examines the system and configures an X screen for  each  display
              device it finds.

       nvidia-xconfig --mode=1600x1200
              Adds a 1600x1200 mode to an existing X configuration.

       nvidia-xconfig --mode-list=1600x1200 1280x1024
              Removes any existing modes from the X configuration file, replac-
              ing them with "1600x1200" and "1280x1024".

       nvidia-xconfig --metamodes=1024x768 +0+0, 1024x768 +1024+0
              Adds the MetaMode "1024x768 +0+0, 1024x768 +1024+0" to the exist-
              ing X configuration file, replacing any existing MetaModes X con-
              figuration option.

       nvidia-xconfig --only-one-x-screen --sli=Auto
              Configures  the  X server to have just one X screen that will use
              SLI when available.

AUTHOR
       Aaron Plattner
       NVIDIA Corporation

SEE ALSO
       nvidia-settings(1), /usr/share/doc/NVIDIA_GLX-1.0/README.txt

COPYRIGHT
       Copyright © 2005-2010 NVIDIA Corporation.

nvidia-xconfig 615.71.09           2026-09-09                 nvidia-xconfig(1)

Generated by dwww version 1.16 on Sat Oct 3 07:42:14 CEST 2026.